@@ -1,6 +1,6 @@
 import logging
 import uuid
-from typing import Dict, List, Union
+from typing import Dict, List, Optional, Union
 
 import shibari
 
@@ -68,6 +68,9 @@ class Client:
     Attributes:
         headers: Dictionary containing all Client-level headers.
 
+        request_kwargs: Dictionary of any arguments to send with every
+            request. Applies to all registered Routes.
+
         logger: Unique logger instance for each Client instance.
 
         request_metadata: Dictionary of relevant metadata from
@@ -89,14 +92,17 @@ class Client:
 
     route_paths: List[str] = []
 
-    def __init__(self, base_uri: str):
+    def __init__(self, base_uri: str, auth=None):
         self.base_uri = base_uri
+        self.auth = auth
 
         for route in self.route_paths:
             self.add_route(route)
 
         self.headers = HeaderDict()
 
+        self.request_kwargs: dict[Optional[str], Optional[str]] = {}
+
         self.logger = logging.getLogger(f'{__name__} {str(uuid.uuid4())}')
         self.logger.addHandler(logging.NullHandler())
 
