@@ -63,6 +63,7 @@ class Route:
         self.prev_kwargs: Mapping[str, str] = {}
 
         self.session = requests.Session()
+        self.session.auth = self.client.auth
 
     def __deepcopy__(self, memodict):
         """Copy in such a way as to avoid copying the client object."""
@@ -176,11 +177,16 @@ class Route:
 
         self.client.log_request(request_metadata)
 
+        evaluated_kwargs: Dict[str, str] = {
+            **kwargs,
+            **self.client.request_kwargs,
+        }
+
         response = self.session.request(
             http_method,
             self.url,
             headers=evaluated_headers,
-            **kwargs,
+            **evaluated_kwargs,
         )
 
         response_metadata = {
